Bundled simple formats: codecs and containers that are small and standard enough to share one crate. Anything larger gets its own crate.
Modules
- filter
- Small image-filter primitives, grouped here while there are too few to deserve their own crate.
- pcm
- PCM codec: uncompressed interleaved linear PCM.
- slin
- Asterisk-style headerless signed-linear PCM container (
.sln/.slin*). - wav
- Minimal pure-Rust RIFF/WAVE container.
- y4m
- YUV4MPEG2 (
.y4m) raw-video container.
Functions
- register
- Unified entry point: install every codec and container provided by
oxideav-basicinto aRuntimeContext. - register_
codecs - Register every codec provided by
oxideav-basicin aCodecRegistry. - register_
containers - Register every container provided by
oxideav-basicin aContainerRegistry.