probe

Function probe 

pub fn probe(p: &ProbeData<'_>) -> u8
Raw PCM has no magic bytes, so this probe is only able to fire on the file extension. Returns PROBE_SCORE_EXTENSION (25) when an .sln* / .slin* extension is supplied and 0 otherwise — a weak hint that any real container probe will outrank.